# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .app_auth_scheme_auth_mode import AppAuthSchemeAuthMode
import typing
from .auth_scheme_field import AuthSchemeField
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AppAuthScheme(UncheckedBaseModel):
    """
    App authenticatio scheme.
    """

    scheme_name: str
    auth_mode: AppAuthSchemeAuthMode
    fields: typing.List[AuthSchemeField]
    proxy: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    authorization_url: typing.Optional[str] = None
    token_url: typing.Optional[str] = None
    default_scopes: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    token_response_metadata: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    client_id: typing.Optional[str] = None
    client_secret: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

AppAuthSchemeAuthMode = typing.Union[
    typing.Literal[
        "OAUTH2",
        "OAUTH1",
        "API_KEY",
        "BASIC",
        "BEARER_TOKEN",
        "BASIC_WITH_JWT",
        "GOOGLE_SERVICE_ACCOUNT",
        "GOOGLEADS_AUTH",
        "NO_AUTH",
        "CALCOM_AUTH",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
from .manager_type import ManagerType
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class Group(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    The id of the group. Assigned by the database.
    """

    manager_type: ManagerType = pydantic.Field()
    """
    
    """

    agent_ids: typing.List[str] = pydantic.Field()
    """
    
    """

    description: str = pydantic.Field()
    """
    
    """

    shared_block_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    
    """

    manager_agent_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    
    """

    termination_token: typing.Optional[str] = pydantic.Field(default=None)
    """
    
    """

    max_turns: typing.Optional[int] = pydantic.Field(default=None)
    """
    
    """

    sleeptime_agent_frequency: typing.Optional[int] = pydantic.Field(default=None)
    """
    
    """

    turns_counter: typing.Optional[int] = pydantic.Field(default=None)
    """
    
    """

    last_processed_message_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    
    """

    max_message_buffer_length: typing.Optional[int] = pydantic.Field(default=None)
    """
    The desired maximum length of messages in the context window of the convo agent. This is a best effort, and may be off slightly due to user/assistant interleaving.
    """

    min_message_buffer_length: typing.Optional[int] = pydantic.Field(default=None)
    """
    The desired minimum length of messages in the context window of the convo agent. This is a best effort, and may be off-by-one due to user/assistant interleaving.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .action_model import ActionModel
from .action_parameters_model import ActionParametersModel
from .action_response_model import ActionResponseModel
from .agent_environment_variable import AgentEnvironmentVariable
from .agent_schema import AgentSchema
from .agent_schema_tool_rules_item import AgentSchemaToolRulesItem
from .agent_state import AgentState
from .agent_state_response_format import AgentStateResponseFormat
from .agent_state_tool_rules_item import AgentStateToolRulesItem
from .agent_type import AgentType
from .app_auth_scheme import AppAuthScheme
from .app_auth_scheme_auth_mode import AppAuthSchemeAuthMode
from .app_model import AppModel
from .assistant_message import AssistantMessage
from .assistant_message_content import AssistantMessageContent
from .audio import Audio
from .auth_request import AuthRequest
from .auth_response import AuthResponse
from .auth_scheme_field import AuthSchemeField
from .bad_request_error_body import BadRequestErrorBody
from .base_64_image import Base64Image
from .base_tool_rule_schema import BaseToolRuleSchema
from .batch_job import BatchJob
from .block import Block
from .block_update import BlockUpdate
from .chat_completion_assistant_message_param import ChatCompletionAssistantMessageParam
from .chat_completion_assistant_message_param_content import ChatCompletionAssistantMessageParamContent
from .chat_completion_assistant_message_param_content_item import ChatCompletionAssistantMessageParamContentItem
from .chat_completion_audio_param import ChatCompletionAudioParam
from .chat_completion_audio_param_format import ChatCompletionAudioParamFormat
from .chat_completion_audio_param_voice import ChatCompletionAudioParamVoice
from .chat_completion_content_part_image_param import ChatCompletionContentPartImageParam
from .chat_completion_content_part_input_audio_param import ChatCompletionContentPartInputAudioParam
from .chat_completion_content_part_refusal_param import ChatCompletionContentPartRefusalParam
from .chat_completion_content_part_text_param import ChatCompletionContentPartTextParam
from .chat_completion_developer_message_param import ChatCompletionDeveloperMessageParam
from .chat_completion_developer_message_param_content import ChatCompletionDeveloperMessageParamContent
from .chat_completion_function_call_option_param import ChatCompletionFunctionCallOptionParam
from .chat_completion_function_message_param import ChatCompletionFunctionMessageParam
from .chat_completion_message_tool_call import ChatCompletionMessageToolCall
from .chat_completion_message_tool_call_param import ChatCompletionMessageToolCallParam
from .chat_completion_named_tool_choice_param import ChatCompletionNamedToolChoiceParam
from .chat_completion_prediction_content_param import ChatCompletionPredictionContentParam
from .chat_completion_prediction_content_param_content import ChatCompletionPredictionContentParamContent
from .chat_completion_stream_options_param import ChatCompletionStreamOptionsParam
from .chat_completion_system_message_param import ChatCompletionSystemMessageParam
from .chat_completion_system_message_param_content import ChatCompletionSystemMessageParamContent
from .chat_completion_tool_message_param import ChatCompletionToolMessageParam
from .chat_completion_tool_message_param_content import ChatCompletionToolMessageParamContent
from .chat_completion_tool_param import ChatCompletionToolParam
from .chat_completion_user_message_param import ChatCompletionUserMessageParam
from .chat_completion_user_message_param_content import ChatCompletionUserMessageParamContent
from .chat_completion_user_message_param_content_item import ChatCompletionUserMessageParamContentItem
from .child_tool_rule import ChildToolRule
from .child_tool_rule_schema import ChildToolRuleSchema
from .completion_create_params_non_streaming import CompletionCreateParamsNonStreaming
from .completion_create_params_non_streaming_function_call import CompletionCreateParamsNonStreamingFunctionCall
from .completion_create_params_non_streaming_messages_item import CompletionCreateParamsNonStreamingMessagesItem
from .completion_create_params_non_streaming_modalities_item import CompletionCreateParamsNonStreamingModalitiesItem
from .completion_create_params_non_streaming_model import CompletionCreateParamsNonStreamingModel
from .completion_create_params_non_streaming_reasoning_effort import CompletionCreateParamsNonStreamingReasoningEffort
from .completion_create_params_non_streaming_response_format import CompletionCreateParamsNonStreamingResponseFormat
from .completion_create_params_non_streaming_service_tier import CompletionCreateParamsNonStreamingServiceTier
from .completion_create_params_non_streaming_stop import CompletionCreateParamsNonStreamingStop
from .completion_create_params_non_streaming_tool_choice import CompletionCreateParamsNonStreamingToolChoice
from .completion_create_params_streaming import CompletionCreateParamsStreaming
from .completion_create_params_streaming_function_call import CompletionCreateParamsStreamingFunctionCall
from .completion_create_params_streaming_messages_item import CompletionCreateParamsStreamingMessagesItem
from .completion_create_params_streaming_modalities_item import CompletionCreateParamsStreamingModalitiesItem
from .completion_create_params_streaming_model import CompletionCreateParamsStreamingModel
from .completion_create_params_streaming_reasoning_effort import CompletionCreateParamsStreamingReasoningEffort
from .completion_create_params_streaming_response_format import CompletionCreateParamsStreamingResponseFormat
from .completion_create_params_streaming_service_tier import CompletionCreateParamsStreamingServiceTier
from .completion_create_params_streaming_stop import CompletionCreateParamsStreamingStop
from .completion_create_params_streaming_tool_choice import CompletionCreateParamsStreamingToolChoice
from .components_schemas_text_content import ComponentsSchemasTextContent
from .conditional_tool_rule import ConditionalToolRule
from .conditional_tool_rule_schema import ConditionalToolRuleSchema
from .conflict_error_body import ConflictErrorBody
from .context_window_overview import ContextWindowOverview
from .continue_tool_rule import ContinueToolRule
from .core_memory_block_schema import CoreMemoryBlockSchema
from .create_block import CreateBlock
from .dynamic_manager import DynamicManager
from .dynamic_manager_update import DynamicManagerUpdate
from .e_2_b_sandbox_config import E2BSandboxConfig
from .embedding_config import EmbeddingConfig
from .embedding_config_embedding_endpoint_type import EmbeddingConfigEmbeddingEndpointType
from .feedback_type import FeedbackType
from .file import File
from .file_file import FileFile
from .file_metadata import FileMetadata
from .file_processing_status import FileProcessingStatus
from .function_call import FunctionCall
from .function_definition_input import FunctionDefinitionInput
from .function_definition_output import FunctionDefinitionOutput
from .function_output import FunctionOutput
from .function_tool import FunctionTool
from .group import Group
from .health import Health
from .hidden_reasoning_message import HiddenReasoningMessage
from .hidden_reasoning_message_state import HiddenReasoningMessageState
from .http_validation_error import HttpValidationError
from .identity import Identity
from .identity_property import IdentityProperty
from .identity_property_type import IdentityPropertyType
from .identity_property_value import IdentityPropertyValue
from .identity_type import IdentityType
from .image_content import ImageContent
from .image_content_source import ImageContentSource
from .image_url import ImageUrl
from .image_url_detail import ImageUrlDetail
from .init_tool_rule import InitToolRule
from .input_audio import InputAudio
from .input_audio_format import InputAudioFormat
from .internal_server_error_body import InternalServerErrorBody
from .job import Job
from .job_status import JobStatus
from .job_type import JobType
from .json_object_response_format import JsonObjectResponseFormat
from .json_schema import JsonSchema
from .json_schema_response_format import JsonSchemaResponseFormat
from .letta_batch_messages import LettaBatchMessages
from .letta_batch_request import LettaBatchRequest
from .letta_image import LettaImage
from .letta_message_content_union import LettaMessageContentUnion
from .letta_message_union import LettaMessageUnion
from .letta_request import LettaRequest
from .letta_request_config import LettaRequestConfig
from .letta_response import LettaResponse
from .letta_stop_reason import LettaStopReason
from .letta_streaming_request import LettaStreamingRequest
from .letta_usage_statistics import LettaUsageStatistics
from .letta_user_message_content_union import LettaUserMessageContentUnion
from .llm_config import LlmConfig
from .llm_config_model_endpoint_type import LlmConfigModelEndpointType
from .llm_config_reasoning_effort import LlmConfigReasoningEffort
from .local_sandbox_config import LocalSandboxConfig
from .manager_type import ManagerType
from .max_count_per_step_tool_rule import MaxCountPerStepToolRule
from .max_count_per_step_tool_rule_schema import MaxCountPerStepToolRuleSchema
from .mcp_server_type import McpServerType
from .mcp_tool import McpTool
from .memory import Memory
from .message import Message
from .message_content_item import MessageContentItem
from .message_create import MessageCreate
from .message_create_content import MessageCreateContent
from .message_create_role import MessageCreateRole
from .message_role import MessageRole
from .message_schema import MessageSchema
from .message_type import MessageType
from .not_found_error_body import NotFoundErrorBody
from .not_found_error_body_message import NotFoundErrorBodyMessage
from .omitted_reasoning_content import OmittedReasoningContent
from .openai_types_chat_chat_completion_message_tool_call_param_function import (
    OpenaiTypesChatChatCompletionMessageToolCallParamFunction,
)
from .openai_types_chat_chat_completion_named_tool_choice_param_function import (
    OpenaiTypesChatChatCompletionNamedToolChoiceParamFunction,
)
from .openai_types_chat_completion_create_params_function import OpenaiTypesChatCompletionCreateParamsFunction
from .organization import Organization
from .organization_create import OrganizationCreate
from .organization_update import OrganizationUpdate
from .parameter_properties import ParameterProperties
from .parameters_schema import ParametersSchema
from .parent_tool_rule import ParentToolRule
from .passage import Passage
from .payment_required_error_body import PaymentRequiredErrorBody
from .pip_requirement import PipRequirement
from .provider import Provider
from .provider_category import ProviderCategory
from .provider_check import ProviderCheck
from .provider_trace import ProviderTrace
from .provider_type import ProviderType
from .reasoning_content import ReasoningContent
from .reasoning_message import ReasoningMessage
from .reasoning_message_source import ReasoningMessageSource
from .redacted_reasoning_content import RedactedReasoningContent
from .required_before_exit_tool_rule import RequiredBeforeExitToolRule
from .response_format_json_object import ResponseFormatJsonObject
from .response_format_json_schema import ResponseFormatJsonSchema
from .response_format_text import ResponseFormatText
from .round_robin_manager import RoundRobinManager
from .round_robin_manager_update import RoundRobinManagerUpdate
from .run import Run
from .sandbox_config import SandboxConfig
from .sandbox_config_create import SandboxConfigCreate
from .sandbox_config_create_config import SandboxConfigCreateConfig
from .sandbox_config_update import SandboxConfigUpdate
from .sandbox_config_update_config import SandboxConfigUpdateConfig
from .sandbox_environment_variable import SandboxEnvironmentVariable
from .sandbox_environment_variable_create import SandboxEnvironmentVariableCreate
from .sandbox_environment_variable_update import SandboxEnvironmentVariableUpdate
from .sandbox_type import SandboxType
from .sleeptime_manager import SleeptimeManager
from .sleeptime_manager_update import SleeptimeManagerUpdate
from .source import Source
from .sse_server_config import SseServerConfig
from .stdio_server_config import StdioServerConfig
from .step import Step
from .step_feedback import StepFeedback
from .stop_reason_type import StopReasonType
from .streamable_http_server_config import StreamableHttpServerConfig
from .supervisor_manager import SupervisorManager
from .supervisor_manager_update import SupervisorManagerUpdate
from .system_message import SystemMessage
from .tag_schema import TagSchema
from .terminal_tool_rule import TerminalToolRule
from .text_content import TextContent
from .text_response_format import TextResponseFormat
from .tool import Tool
from .tool_annotations import ToolAnnotations
from .tool_call import ToolCall
from .tool_call_content import ToolCallContent
from .tool_call_delta import ToolCallDelta
from .tool_call_message import ToolCallMessage
from .tool_call_message_tool_call import ToolCallMessageToolCall
from .tool_create import ToolCreate
from .tool_env_var_schema import ToolEnvVarSchema
from .tool_json_schema import ToolJsonSchema
from .tool_return import ToolReturn
from .tool_return_content import ToolReturnContent
from .tool_return_message import ToolReturnMessage
from .tool_return_message_status import ToolReturnMessageStatus
from .tool_return_status import ToolReturnStatus
from .tool_schema import ToolSchema
from .tool_type import ToolType
from .update_assistant_message import UpdateAssistantMessage
from .update_assistant_message_content import UpdateAssistantMessageContent
from .update_reasoning_message import UpdateReasoningMessage
from .update_ssemcp_server import UpdateSsemcpServer
from .update_streamable_httpmcp_server import UpdateStreamableHttpmcpServer
from .update_system_message import UpdateSystemMessage
from .update_user_message import UpdateUserMessage
from .update_user_message_content import UpdateUserMessageContent
from .url_image import UrlImage
from .usage_statistics import UsageStatistics
from .usage_statistics_completion_token_details import UsageStatisticsCompletionTokenDetails
from .usage_statistics_prompt_token_details import UsageStatisticsPromptTokenDetails
from .user import User
from .user_create import UserCreate
from .user_message import UserMessage
from .user_message_content import UserMessageContent
from .user_update import UserUpdate
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .voice_sleeptime_manager import VoiceSleeptimeManager
from .voice_sleeptime_manager_update import VoiceSleeptimeManagerUpdate
from .web_search_options import WebSearchOptions
from .web_search_options_search_context_size import WebSearchOptionsSearchContextSize
from .web_search_options_user_location import WebSearchOptionsUserLocation
from .web_search_options_user_location_approximate import WebSearchOptionsUserLocationApproximate

__all__ = [
    "ActionModel",
    "ActionParametersModel",
    "ActionResponseModel",
    "AgentEnvironmentVariable",
    "AgentSchema",
    "AgentSchemaToolRulesItem",
    "AgentState",
    "AgentStateResponseFormat",
    "AgentStateToolRulesItem",
    "AgentType",
    "AppAuthScheme",
    "AppAuthSchemeAuthMode",
    "AppModel",
    "AssistantMessage",
    "AssistantMessageContent",
    "Audio",
    "AuthRequest",
    "AuthResponse",
    "AuthSchemeField",
    "BadRequestErrorBody",
    "Base64Image",
    "BaseToolRuleSchema",
    "BatchJob",
    "Block",
    "BlockUpdate",
    "ChatCompletionAssistantMessageParam",
    "ChatCompletionAssistantMessageParamContent",
    "ChatCompletionAssistantMessageParamContentItem",
    "ChatCompletionAudioParam",
    "ChatCompletionAudioParamFormat",
    "ChatCompletionAudioParamVoice",
    "ChatCompletionContentPartImageParam",
    "ChatCompletionContentPartInputAudioParam",
    "ChatCompletionContentPartRefusalParam",
    "ChatCompletionContentPartTextParam",
    "ChatCompletionDeveloperMessageParam",
    "ChatCompletionDeveloperMessageParamContent",
    "ChatCompletionFunctionCallOptionParam",
    "ChatCompletionFunctionMessageParam",
    "ChatCompletionMessageToolCall",
    "ChatCompletionMessageToolCallParam",
    "ChatCompletionNamedToolChoiceParam",
    "ChatCompletionPredictionContentParam",
    "ChatCompletionPredictionContentParamContent",
    "ChatCompletionStreamOptionsParam",
    "ChatCompletionSystemMessageParam",
    "ChatCompletionSystemMessageParamContent",
    "ChatCompletionToolMessageParam",
    "ChatCompletionToolMessageParamContent",
    "ChatCompletionToolParam",
    "ChatCompletionUserMessageParam",
    "ChatCompletionUserMessageParamContent",
    "ChatCompletionUserMessageParamContentItem",
    "ChildToolRule",
    "ChildToolRuleSchema",
    "CompletionCreateParamsNonStreaming",
    "CompletionCreateParamsNonStreamingFunctionCall",
    "CompletionCreateParamsNonStreamingMessagesItem",
    "CompletionCreateParamsNonStreamingModalitiesItem",
    "CompletionCreateParamsNonStreamingModel",
    "CompletionCreateParamsNonStreamingReasoningEffort",
    "CompletionCreateParamsNonStreamingResponseFormat",
    "CompletionCreateParamsNonStreamingServiceTier",
    "CompletionCreateParamsNonStreamingStop",
    "CompletionCreateParamsNonStreamingToolChoice",
    "CompletionCreateParamsStreaming",
    "CompletionCreateParamsStreamingFunctionCall",
    "CompletionCreateParamsStreamingMessagesItem",
    "CompletionCreateParamsStreamingModalitiesItem",
    "CompletionCreateParamsStreamingModel",
    "CompletionCreateParamsStreamingReasoningEffort",
    "CompletionCreateParamsStreamingResponseFormat",
    "CompletionCreateParamsStreamingServiceTier",
    "CompletionCreateParamsStreamingStop",
    "CompletionCreateParamsStreamingToolChoice",
    "ComponentsSchemasTextContent",
    "ConditionalToolRule",
    "ConditionalToolRuleSchema",
    "ConflictErrorBody",
    "ContextWindowOverview",
    "ContinueToolRule",
    "CoreMemoryBlockSchema",
    "CreateBlock",
    "DynamicManager",
    "DynamicManagerUpdate",
    "E2BSandboxConfig",
    "EmbeddingConfig",
    "EmbeddingConfigEmbeddingEndpointType",
    "FeedbackType",
    "File",
    "FileFile",
    "FileMetadata",
    "FileProcessingStatus",
    "FunctionCall",
    "FunctionDefinitionInput",
    "FunctionDefinitionOutput",
    "FunctionOutput",
    "FunctionTool",
    "Group",
    "Health",
    "HiddenReasoningMessage",
    "HiddenReasoningMessageState",
    "HttpValidationError",
    "Identity",
    "IdentityProperty",
    "IdentityPropertyType",
    "IdentityPropertyValue",
    "IdentityType",
    "ImageContent",
    "ImageContentSource",
    "ImageUrl",
    "ImageUrlDetail",
    "InitToolRule",
    "InputAudio",
    "InputAudioFormat",
    "InternalServerErrorBody",
    "Job",
    "JobStatus",
    "JobType",
    "JsonObjectResponseFormat",
    "JsonSchema",
    "JsonSchemaResponseFormat",
    "LettaBatchMessages",
    "LettaBatchRequest",
    "LettaImage",
    "LettaMessageContentUnion",
    "LettaMessageUnion",
    "LettaRequest",
    "LettaRequestConfig",
    "LettaResponse",
    "LettaStopReason",
    "LettaStreamingRequest",
    "LettaUsageStatistics",
    "LettaUserMessageContentUnion",
    "LlmConfig",
    "LlmConfigModelEndpointType",
    "LlmConfigReasoningEffort",
    "LocalSandboxConfig",
    "ManagerType",
    "MaxCountPerStepToolRule",
    "MaxCountPerStepToolRuleSchema",
    "McpServerType",
    "McpTool",
    "Memory",
    "Message",
    "MessageContentItem",
    "MessageCreate",
    "MessageCreateContent",
    "MessageCreateRole",
    "MessageRole",
    "MessageSchema",
    "MessageType",
    "NotFoundErrorBody",
    "NotFoundErrorBodyMessage",
    "OmittedReasoningContent",
    "OpenaiTypesChatChatCompletionMessageToolCallParamFunction",
    "OpenaiTypesChatChatCompletionNamedToolChoiceParamFunction",
    "OpenaiTypesChatCompletionCreateParamsFunction",
    "Organization",
    "OrganizationCreate",
    "OrganizationUpdate",
    "ParameterProperties",
    "ParametersSchema",
    "ParentToolRule",
    "Passage",
    "PaymentRequiredErrorBody",
    "PipRequirement",
    "Provider",
    "ProviderCategory",
    "ProviderCheck",
    "ProviderTrace",
    "ProviderType",
    "ReasoningContent",
    "ReasoningMessage",
    "ReasoningMessageSource",
    "RedactedReasoningContent",
    "RequiredBeforeExitToolRule",
    "ResponseFormatJsonObject",
    "ResponseFormatJsonSchema",
    "ResponseFormatText",
    "RoundRobinManager",
    "RoundRobinManagerUpdate",
    "Run",
    "SandboxConfig",
    "SandboxConfigCreate",
    "SandboxConfigCreateConfig",
    "SandboxConfigUpdate",
    "SandboxConfigUpdateConfig",
    "SandboxEnvironmentVariable",
    "SandboxEnvironmentVariableCreate",
    "SandboxEnvironmentVariableUpdate",
    "SandboxType",
    "SleeptimeManager",
    "SleeptimeManagerUpdate",
    "Source",
    "SseServerConfig",
    "StdioServerConfig",
    "Step",
    "StepFeedback",
    "StopReasonType",
    "StreamableHttpServerConfig",
    "SupervisorManager",
    "SupervisorManagerUpdate",
    "SystemMessage",
    "TagSchema",
    "TerminalToolRule",
    "TextContent",
    "TextResponseFormat",
    "Tool",
    "ToolAnnotations",
    "ToolCall",
    "ToolCallContent",
    "ToolCallDelta",
    "ToolCallMessage",
    "ToolCallMessageToolCall",
    "ToolCreate",
    "ToolEnvVarSchema",
    "ToolJsonSchema",
    "ToolReturn",
    "ToolReturnContent",
    "ToolReturnMessage",
    "ToolReturnMessageStatus",
    "ToolReturnStatus",
    "ToolSchema",
    "ToolType",
    "UpdateAssistantMessage",
    "UpdateAssistantMessageContent",
    "UpdateReasoningMessage",
    "UpdateSsemcpServer",
    "UpdateStreamableHttpmcpServer",
    "UpdateSystemMessage",
    "UpdateUserMessage",
    "UpdateUserMessageContent",
    "UrlImage",
    "UsageStatistics",
    "UsageStatisticsCompletionTokenDetails",
    "UsageStatisticsPromptTokenDetails",
    "User",
    "UserCreate",
    "UserMessage",
    "UserMessageContent",
    "UserUpdate",
    "ValidationError",
    "ValidationErrorLocItem",
    "VoiceSleeptimeManager",
    "VoiceSleeptimeManagerUpdate",
    "WebSearchOptions",
    "WebSearchOptionsSearchContextSize",
    "WebSearchOptionsUserLocation",
    "WebSearchOptionsUserLocationApproximate",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.dynamic_manager import DynamicManager
from ...types.round_robin_manager import RoundRobinManager
from ...types.sleeptime_manager import SleeptimeManager
from ...types.supervisor_manager import SupervisorManager
from ...types.voice_sleeptime_manager import VoiceSleeptimeManager

GroupCreateManagerConfig = typing.Union[
    DynamicManager, RoundRobinManager, SleeptimeManager, SupervisorManager, VoiceSleeptimeManager
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .message_create_role import MessageCreateRole
import pydantic
from .message_create_content import MessageCreateContent
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class MessageCreate(UncheckedBaseModel):
    """
    Request to create a message
    """

    role: MessageCreateRole = pydantic.Field()
    """
    The role of the participant.
    """

    content: MessageCreateContent = pydantic.Field()
    """
    The content of the message.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the participant.
    """

    otid: typing.Optional[str] = pydantic.Field(default=None)
    """
    The offline threading id associated with this message
    """

    sender_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The id of the sender of the message, can be an identity id or agent id
    """

    batch_item_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The id of the LLMBatchItem that this message is associated with
    """

    group_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The multi-agent group that the message was sent in
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .tool_return_status import ToolReturnStatus
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ToolReturn(UncheckedBaseModel):
    status: ToolReturnStatus = pydantic.Field()
    """
    The status of the tool call
    """

    stdout: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Captured stdout (e.g. prints, logs) from the tool invocation
    """

    stderr: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Captured stderr from the tool invocation
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import TemplatesListResponse, TemplatesListResponseTemplatesItem
from . import agents
from .agents import AgentsCreateResponse

__all__ = ["AgentsCreateResponse", "TemplatesListResponse", "TemplatesListResponseTemplatesItem", "agents"]



# This file was auto-generated by Fern from our API Definition.

import typing
from ....types.update_system_message import UpdateSystemMessage
from ....types.update_user_message import UpdateUserMessage
from ....types.update_reasoning_message import UpdateReasoningMessage
from ....types.update_assistant_message import UpdateAssistantMessage

MessagesModifyRequest = typing.Union[
    UpdateSystemMessage, UpdateUserMessage, UpdateReasoningMessage, UpdateAssistantMessage
]
